@@ -24,6 +24,8 @@ class RepositoryType(Enum):
     SHAPEFILE = "shapefile"
     SHAPEFILESDIR = "shapefiles-directory"
     ORACLE = "oracle"
+    GEOGIG = "geogig"
+    CASCADEDWMS = "cascaded-wms"
 
 
 class StyleType(Enum):
@@ -41,6 +43,7 @@ class LayerType(Enum):
 
     RASTER = "raster"
     VECTOR = "vector"
+    CASCADEDWMS = "wms"
 
 
 class LayerGeometry(Enum):
@@ -51,6 +54,7 @@ class LayerGeometry(Enum):
     POINT = "point"
     LINESTRING = "linestring"
     POLYGON = "polygon"
+    POLYGON3D = "3d-polygon"
     MULTIPOINT = "multi-point"
     MULTILINESTRING = "multi-linestring"
     MULTIPOLYGON = "multi-polygon"
