@@ -209,6 +209,8 @@ class RepositoryTypeAirtable(Enum):
     SHAPEFILE = "Shapefile"
     SHAPEFILESDIR = "Shapefiles Directory"
     ORACLE = "Oracle"
+    GEOGIG = "GeoGig"
+    CASCADEDWMS = "Cascaded WMS"
 
 
 class StyleTypeAirtable(Enum):
@@ -226,6 +228,7 @@ class LayerTypeAirtable(Enum):
 
     RASTER = "Raster"
     VECTOR = "Vector"
+    CASCADEDWMS = "Cascaded WMS"
 
 
 class LayerGeometryAirtable(Enum):
@@ -236,6 +239,7 @@ class LayerGeometryAirtable(Enum):
     POINT = "Point"
     LINESTRING = "Linestring"
     POLYGON = "Polygon"
+    POLYGON3D = "3D Polygon"
     MULTIPOINT = "Multi-Point"
     MULTILINESTRING = "Multi-Linestring"
     MULTIPOLYGON = "Multi-Polygon"
