@@ -24,6 +24,8 @@ class GeoServerRepositoryType(Enum):
     SHAPEFILE = "shapefile"
     SHAPEFILESDIR = "directory of spatial files (shapefiles)"
     ORACLE = "oracle ng"
+    GEOGIG = "geogig"
+    CASCADEDWMS = "wms"
 
 
 class GeoServerLayerGeometry(Enum):
@@ -34,6 +36,7 @@ class GeoServerLayerGeometry(Enum):
     POINT = "Point"
     LINESTRING = "Linestring"
     POLYGON = "Polygon"
+    POLYGON3D = "3D Polygon"
     MULTIPOINT = "MultiPoint"
     MULTILINESTRING = "MultiLinestring"
     MULTIPOLYGON = "MultiPolygon"
